@@ -1,5 +1,6 @@
 use crate::{Config, CONFIG_FILE, SUMMARY_FILE};
 
+use ignore::{overrides::OverrideBuilder, types::TypesBuilder, WalkBuilder};
 use mdbook::errors::*;
 use std::cmp::Ordering;
 use std::fs::{self, File};
@@ -9,7 +10,6 @@ use std::{
     path::{Component, Path, PathBuf},
     process::Command,
 };
-use ignore::{WalkBuilder, overrides::OverrideBuilder, types::TypesBuilder};
 
 const PAD_SIZE: usize = 4;
 
@@ -65,13 +65,16 @@ pub fn update_summary(config: &Config, root: &Path) -> Result<(), Error> {
     let walker = WalkBuilder::new(&book_source)
         .hidden(true)
         .overrides(overrides.build()?)
-        .types(TypesBuilder::new().add_defaults().select("markdown").build()?)
-        .sort_by_file_path(|path1, path2| {
-            match (path1.is_dir(), path2.is_dir()) {
-                (true, false) => Ordering::Less,
-                (false, true) => Ordering::Greater,
-                _ => path1.cmp(path2),
-            }
+        .types(
+            TypesBuilder::new()
+                .add_defaults()
+                .select("markdown")
+                .build()?,
+        )
+        .sort_by_file_path(|path1, path2| match (path1.is_dir(), path2.is_dir()) {
+            (true, false) => Ordering::Less,
+            (false, true) => Ordering::Greater,
+            _ => path1.cmp(path2),
         })
         .build();
 
@@ -79,13 +82,40 @@ pub fn update_summary(config: &Config, root: &Path) -> Result<(), Error> {
         .filter_map(|e| e.ok())
         // Don't include the book source directory
         .filter(|e| e.path() != book_source && e.path() != book_source.join(SUMMARY_FILE))
+        // Filter files which share the name of it's parent directory.
+        .filter(|e| {
+            if let Some(dir_stem) = e.path().parent() {
+                let dir_stem = dir_stem.file_stem().unwrap_or_default();
+                let file_stem = e.path().file_stem().unwrap_or_default();
+                file_stem != dir_stem
+            } else {
+                true
+            }
+        })
         .map(|e| {
-            let stripped_path = e.path().strip_prefix(&book_source).unwrap();
+            let path = e.path();
+            let stripped_path = path.strip_prefix(&book_source).unwrap();
             let file_stem = stripped_path.file_stem().unwrap().to_str().unwrap();
             let depth = (stripped_path.components().count() - 1) * PAD_SIZE;
 
-            if e.path().is_dir() {
-                format!("{1:>0$}- [{2}]()\n", depth, "", file_stem)
+            if path.is_dir() {
+                let dir_file = stripped_path
+                    .join(&stripped_path.file_stem().unwrap_or_default())
+                    .with_extension("md");
+
+                if book_source.join(&dir_file).is_file() {
+                    // Directory contains equally named file
+                    format!(
+                        "{1:>0$}- [{2}](<{3}>)\n",
+                        depth,
+                        "",
+                        file_stem,
+                        escape_special_chars(dir_file.to_str().unwrap())
+                    )
+                } else {
+                    // Directory has no equally named file
+                    format!("{1:>0$}- [{2}]()\n", depth, "", file_stem)
+                }
             } else {
                 format!(
                     "{1:>0$}- [{2}](<{3}>)\n",
